package com.unis.hlht.server.common.data;

import com.alibaba.druid.spring.boot.autoconfigure.DruidDataSourceBuilder;
import lombok.extern.log4j.Log4j2;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;

import javax.sql.DataSource;


/**
 * 功能描述：druid druid-spring-boot-starter 数据源配置
 *
 * @author 李兵
 * @version v1.0
 * @date 2018/04/21 18:47
 */

@Configuration
@Log4j2
public class DruidConfigs {
    /**
     * Druid tabledata source tabledata source.
     * 1.1.10 配置方式
     *
     * @return tabledata source
     */
    @Primary
    @Bean
    public DataSource druidDataSource() {
        return DruidDataSourceBuilder.create().build();
    }


    /**
     * Data source one druid tabledata source.
     * 1.1.9 配置方式
     * @return the druid tabledata source
     */
//    @Primary
//    @Bean
//    public DataSource druidDataSource(Environment env) {
//        return DruidDataSourceBuilder.create().build( env, "spring.datasource.druid" );
//    }


    /**
     * spring boot 1.5.14 版本配置 需要手动 编写 StatViewServlet  WebStatFilter
     */

    /**
     * Data source one druid tabledata source.
     *
     * @return the druid tabledata source
     */
//    @Primary
//    @Bean
//    public DataSource dataSource(){
//        return DruidDataSourceBuilder.create().build();
//    }

    /**
     * Druid stat view servlet servlet registration bean.
     * StatViewServlet是一个标准的javax.servlet.http.HttpServlet
     * 1.配置url-pattern 根据配置中的url-pattern来访问内置监控页面，如果是上面的配置/druid/*，内置监控页面的首页是/druid/index.html
     * 2配置allow和deny
     * 判断规则:
     * deny优先于allow，如果在deny列表中，就算在allow列表中，也会被拒绝。如果allow没有配置或者为空，则允许所有访问
     * 其中 128.242.127.1/24 24表示，前面24位是子网掩码，比对的时候，前面24位相同就匹配。
     * 不支持IPV6
     * 由于匹配规则不支持IPV6，配置了allow或者deny之后，会导致IPV6无法访问。
     * 3.配置resetEnable 在StatViewSerlvet输出的html页面中，有一个功能是Reset All，执行这个操作之后，会导致所有计数器清零，
     * 重新计数。你可以通过配置参数关闭它。
     *
     * @return the servlet registration bean
     */

//    @Bean
//    public ServletRegistrationBean druidStatViewServlet() {
//        ServletRegistrationBean registrationBean = new ServletRegistrationBean( new StatViewServlet(), "/druid/*" );
//        registrationBean.addInitParameter( "allow", "127.0.0.1" );
//        // IP白名单 (没有配置或者为空，则允许所有访问)
//        registrationBean.addInitParameter( "deny", "" );
//        // IP黑名单 (存在共同时，deny优先于allow)
//        registrationBean.addInitParameter( "loginUsername", "登录druid的用户名" );
//        registrationBean.addInitParameter( "loginPassword", "登录druid的密码" );
//        registrationBean.addInitParameter( "resetEnable", "false" );
//        return registrationBean;
//    }


    /**
     * Druid web stat view filter filter registration bean.
     * WebStatFilter用于采集web-jdbc关联监控的数据。
     * exlusions配置 经常需要排除一些不必要的url，比如.js,/jslib/等等。配置在init-param中。
     * 启动项目后访问http://localhost:8080/druid/index.html 登录后 即可查看数据源及SQL统计等。
     *
     * @return the filter registration bean
     */

//    @Bean
//    public FilterRegistrationBean druidWebStatViewFilter() {
//        FilterRegistrationBean registrationBean = new FilterRegistrationBean( new WebStatFilter() );
//        registrationBean.addInitParameter( "urlPatterns", "/*" );
//        registrationBean.addInitParameter( "exclusions", "*.js,*.gif,*.jpg,*.bmp,*.png,*.css,*.ico,/druid/*" );
//        return registrationBean;
//    }


}
