package com.unis.hlht.server.common.restconfig;

import com.unis.hlht.server.common.UploadResponse;
import com.unis.hlht.server.controller.instruction.InstructionController;
import com.unis.hlht.server.dto.datashare.DataShareParasDTO;
import com.unis.hlht.server.dto.instruction.UpLoadDTO;

import lombok.extern.slf4j.Slf4j;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.springframework.web.client.RestTemplate;

import java.util.Map;

/**
 * @description:国家局接口调用对象
 * @author:马伟栋
 * @version:v1.0
 * @create:2019/02/19-18:57
 **/
@Slf4j
@Component
@SuppressWarnings("all")
public class RestNational {

    @Value("${uploadip}")
    private String uploadIp;

    @Value("${uploadport}")
    private String uploadPort;

    @Value("${uploaduri}")
    private String uploadUri;

    @Value("${datashareip}")
    private String datashareip;

    @Value("${datashareport}")
    private String datashareport;

    @Value("${datashareuri}")
    private String dataShareUri;

    @Autowired
    private RestTemplate restTemplate;

    /**
     * 获取上传URL
     * http://106.3.145.72:49871/dxp/service/API/SECURE/接口名称
     *
     * @return url
     */
    private String getUpLoadUrl() {
        return String.format("http://%s:%s/%s", uploadIp, uploadPort, uploadUri);
    }

    /**
     * 获取数据共享URL
     * http://106.3.145.72:49871/service/API/DOWNLOAD/70101
     *
     * @return url
     */
    private String getDataShareUrl() {
        return String.format("http://%s:%s/%s", datashareip, datashareport, dataShareUri);
    }


    /**
     * 数据上传至国家平台
     *
     * @param dto
     * @return
     */
    public UploadResponse uploadData2National(UpLoadDTO dto, String api) {
        return restTemplate.postForObject(getUpLoadUrl() + api, dto, UploadResponse.class);
    }

    /**
     * 省平台获取共享数据
     *
     * @param dto
     * @param api
     * @return
     */
    public Map dataShareFromNational(DataShareParasDTO dto, String api) {
        return restTemplate.postForObject(getDataShareUrl() + api, dto, Map.class);
    }

}
