package com.unis.hlht.server.controller.instruction;

import com.alibaba.fastjson.JSON;

import com.unis.hlht.server.dto.instruction.InstructionParasDTO;
import com.unis.hlht.server.enums.instruction.InstructionTypeEnum;
import com.unis.hlht.server.mapper.apimappingtable.ApiMappingTableMapper;
import com.unis.hlht.server.server.instruction.InstructionServer;
import com.unis.hlht.server.utils.RedisUtils;
import com.unis.hlht.server.utils.ResponseCode;
import io.swagger.annotations.Api;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @description:指令接口
 * @author:马伟栋
 * @version:v1.0
 * @create:2019/02/19-14:05
 **/
@Slf4j
@RestController
@RequestMapping("/instruction")
@Api(tags = "指令")
@SuppressWarnings("all")
public class InstructionController {

    @Autowired
    private RedisUtils redisUtils;

    @Autowired
    private InstructionServer server;

    @Autowired
    private ApiMappingTableMapper mappingTableMapper;

    @PostMapping("/issued")
    public ResponseCode receiveInstruction(@RequestBody InstructionParasDTO dto) {
        try {
            log.info("接收指令信息:" + JSON.toJSONString(dto));
            String type = dto.getType();
            //指令类型为空无法解析
            if (type == null) {
                log.info("指令类型数据为null:无法解析!");
                return ResponseCode.error();
            }
            if (type.equals(InstructionTypeEnum.hearBeatInstruction.getCode())) {
                //心跳指令
                return server.heartBeat();
            } else if (type.equals(InstructionTypeEnum.dataInstruction.getCode())) {
                //数据指令
                return server.dataUpload(dto);
            } else {
                log.info("指令类型数据错误:无法解析!");
                return ResponseCode.error();
            }
        } catch (Exception e) {
            log.error("执行指令错误", e);
            e.printStackTrace();
            return ResponseCode.error();
        }
    }

}
