package com.unis.hlht.server.mapper.tabledata;

import com.unis.hlht.server.factory.ActivationProvider;
import com.unis.hlht.server.mapper.MyMapper;
import com.unis.hlht.server.po.table.TableInfoPO;
import org.apache.ibatis.annotations.InsertProvider;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;
import org.apache.ibatis.annotations.Update;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Map;

/**
 * @description:表数据访问对象
 * @author:马伟栋
 * @version:v1.0
 * @create:2019/02/19-16:34
 **/
@SuppressWarnings("all")
@Repository
public interface TableDataMapper extends MyMapper<Map> {

    @Select({"<script>"
            + "SELECT t.* FROM ${tableName} t where is_upload = 0 ",
            "<if test = 'startTime != null'>",
            /*"and str_to_date(zhgxsj,'yyyy-MM-dd HH24:MI:SS') &gt;= str_to_date(#{startTime},'yyyy-MM-dd HH24:MI:SS')",*/
            "and (zhgxsj) &gt;= (#{startTime})",
            "</if>",
            "<if test = 'endTime != null'>",
            /*"and str_to_date(zhgxsj,'yyyy-MM-dd HH24:MI:SS') &lt;= str_to_date(#{endTime},'yyyy-MM-dd HH24:MI:SS')",*/
            "and (zhgxsj) &lt;= (#{endTime})",
            "</if>",
            "<if test = 'depDwdm != null'>",
            "and ${selectByDwdmOfCol} like #{depDwdm}",
            "</if>",
            "limit #{pageIndex},#{pageSize}",
            "</script>"})
    List<Map> findAllByLoadDate(Map params);

    @Select({"<script> SELECT * FROM ( "
            + "SELECT t.*,rownum num FROM ${tableName} t where is_upload = 0 and id = #{busId}"
            +" ) a limit #{pageIndex},#{pageSize}",
            "</script>"})
    List<Map> findById(@Param("tableName") String tableName, @Param("busId") String busId,
                       @Param("pageSize") Integer pageSize, @Param("pageIndex") Integer pageIndex);

    @Select({"<script> SELECT count(*)  FROM ${tableName} where is_upload = 0 ",
            "<if test = 'startTime != null'>",
            /*"and str_to_date(zhgxsj,'yyyy-MM-dd HH24:MI:SS') &gt;= str_to_date(#{startTime},'yyyy-MM-dd HH24:MI:SS')",*/
            "and (zhgxsj) &gt;= (#{startTime})",
            "</if>",
            "<if test = 'endTime != null'>",
            /*"and str_to_date(zhgxsj,'yyyy-MM-dd HH24:MI:SS') &lt;= str_to_date(#{endTime},'yyyy-MM-dd HH24:MI:SS')",*/
            "and (zhgxsj) &lt;= (#{endTime})",
            "</if>",
            "<if test = 'depDwdm != null'>",
            "and ${selectByDwdmOfCol} like #{depDwdm} ",
            "</if>",
            "</script>"})
    Integer findDataCount(Map params);

    @Select({"<script> SELECT count(*)  FROM ${tableName} where is_upload = 0 and id = #{id}",
            "</script>"})
    Integer findDataCountById(@Param("tableName") String tableName, @Param("id") String id);

    @InsertProvider(type = ActivationProvider.class, method = "insertShareDataSql")
    boolean insertShareDataToDB(String data, String tableName, List<TableInfoPO> columnNames);

    @Select("select column_name as columnName,data_type as dataType from user_tab_columns where Table_Name = #{tableName}")
    List<TableInfoPO> findColumnNameAndDataTypeByTableName(String tableName);

    @Update({
            "<script>",
            "<foreach collection = 'ids' item = 'item' separator = ';' open='begin' close=';end;'>",
            "update ${tableName} set is_upload = 1 where id = #{item}",
            "</foreach>",
            "</script>"})
    void updateIsUploadToTrueByIds(Map params);
    
    
    /**
     * 温湿度
     * @param params
     * @return
     */
    @Select({"<script> SELECT * FROM ( "
            + "SELECT t.WSDJCDH,t.JCSJ,t.HWDM,t.CFWW,t.CFWS,t.CFNW,t.CFNS,t.LSZGW,t.LSZDW,t.LSPJW,REPLACE(t.LSSDZJH,CHR(0),'') as LSSDZJH,t.CZBZ,t.ZHGXSJ,"
            + "t.id,t.IS_UPLOAD,t.LOAD_DATE,t.DEP_DWDM,t.DEP_KQDM,t.TYHWBM,REPLACE(t.LSWDZJH,CHR(0),'') as LSWDZJH"
    		+"FROM ${tableName} t where is_upload = 0 ",
            "<if test = 'startTime != null'>",
            /*"and str_to_date(zhgxsj,'yyyy-MM-dd HH24:MI:SS') &gt;= str_to_date(#{startTime},'yyyy-MM-dd HH24:MI:SS')",*/
            "and (zhgxsj) &gt;= (#{startTime})",
            "</if>",
            "<if test = 'endTime != null'>",
            /*"and str_to_date(zhgxsj,'yyyy-MM-dd HH24:MI:SS') &lt;= str_to_date(#{endTime},'yyyy-MM-dd HH24:MI:SS')",*/
            "and (zhgxsj) &lt;= (#{endTime})",
            "</if>",
            "<if test = 'depDwdm != null'>",
            "and ${selectByDwdmOfCol} like #{depDwdm}",
            "</if>",
            ") a limit #{pageIndex},#{pageSize}",
            "</script>"})
    List<Map> findAllByLoadDateLOB(Map params);
    
    
    
    @Select({"<script> SELECT * FROM ( "
    		+ "SELECT t.WSDJCDH,t.JCSJ,t.HWDM,t.CFWW,t.CFWS,t.CFNW,t.CFNS,t.LSZGW,t.LSZDW,t.LSPJW,REPLACE(t.LSSDZJH,CHR(0),'') as LSSDZJH,t.CZBZ,t.ZHGXSJ,"
            + "t.id,t.IS_UPLOAD,t.LOAD_DATE,t.DEP_DWDM,t.DEP_KQDM,t.TYHWBM,REPLACE(t.LSWDZJH,CHR(0),'') as LSWDZJH"
            + "FROM ${tableName} t where is_upload = 0 and id = #{busId}",
            " ) a limit #{pageIndex},#{pageSize}",
            "</script>"})
    List<Map> findByIdLOB(@Param("tableName") String tableName, @Param("busId") String busId,
                       @Param("pageSize") Integer pageSize, @Param("pageIndex") Integer pageIndex);

    
    
    @Select({"<script> SELECT * FROM ( "
            + "SELECT QTNDJCDH,JCSJ,HWDM,CZBZ,ZHGXSJ,id,IS_UPLOAD,LOAD_DATE,DEP_DWDM,DEP_KQDM,ZYLX,TYHWBM,"
    		+"REPLACE(t.YQHLZJH,CHR(0),'') as YQHLZJH,REPLACE(t.EYHTHLZJH,CHR(0),'') as EYHTHLZJH,"
            +"REPLACE(t.LXFNDZJH,CHR(0),'') as LXFNDZJH,REPLACE(t.LHQNDZJH,CHR(0),'') as LHQNDZJH,"
    		+"REPLACE(t.YYHDHLZJH,CHR(0),'') as YYHDHLZJH,REPLACE(t.YYHTHLZJH,CHR(0),'') as YYHTHLZJH"
            + "FROM ${tableName} t where is_upload = 0 and id = #{busId}",
            " )a limit #{pageIndex},#{pageSize}",
            "</script>"})
    List<Map> findByIdQt(@Param("tableName") String tableName, @Param("busId") String busId,
                       @Param("pageSize") Integer pageSize, @Param("pageIndex") Integer pageIndex);
    
    
    @Select({"<script> SELECT * FROM ( "
            + "SELECT QTNDJCDH,JCSJ,HWDM,CZBZ,ZHGXSJ,id,IS_UPLOAD,LOAD_DATE,DEP_DWDM,DEP_KQDM,ZYLX,TYHWBM,"
            +"REPLACE(t.YQHLZJH,CHR(0),'') as YQHLZJH,REPLACE(t.EYHTHLZJH,CHR(0),'') as EYHTHLZJH,"
            +"REPLACE(t.LXFNDZJH,CHR(0),'') as LXFNDZJH,REPLACE(t.LHQNDZJH,CHR(0),'') as LHQNDZJH,"
    		+"REPLACE(t.YYHDHLZJH,CHR(0),'') as YYHDHLZJH,REPLACE(t.YYHTHLZJH,CHR(0),'') as YYHTHLZJH"
    		+"FROM ${tableName} t where is_upload = 0 ",
            "<if test = 'startTime != null'>",
            /*"and str_to_date(zhgxsj,'yyyy-MM-dd HH24:MI:SS') &gt;= str_to_date(#{startTime},'yyyy-MM-dd HH24:MI:SS')",*/
            "and (zhgxsj) &gt;= (#{startTime})",
            "</if>",
            "<if test = 'endTime != null'>",
            /*"and str_to_date(zhgxsj,'yyyy-MM-dd HH24:MI:SS') &lt;= str_to_date(#{endTime},'yyyy-MM-dd HH24:MI:SS')",*/
            "and (zhgxsj) &lt;= (#{endTime})",
            "</if>",
            "<if test = 'depDwdm != null'>",
            "and ${selectByDwdmOfCol} like #{depDwdm}",
            "</if>",
            ") a limit #{pageIndex},#{pageSize}",
            "</script>"})
    List<Map> findAllByLoadDateQt(Map params);

}
