package com.unis.hlht.server.redisstream;

import com.unis.hlht.server.server.message.MessageServer;
import io.netty.util.internal.UnstableApi;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.connection.stream.MapRecord;
import org.springframework.data.redis.connection.stream.RecordId;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.stream.StreamListener;
import org.springframework.stereotype.Component;

import java.util.Map;

@Slf4j
@Component
public class BasicAckStreamConsumeListener implements StreamListener<String, MapRecord<String, String, String>> {

    /**
     * 分组名
     */
    public static final String GROUP = "basicack_stream";

    /**
     * 队列名
     */
    public static final String NOTICE_UPLOAD_STREAM_KEY = "notice_upload";

    /**
     * 消费者名称
     */
    public static final String NOTICE_UPLOAD_CONSUMER = "BasicAckConsumer";

    @Autowired
    private RedisTemplate<String, Object> redisTemplate;

    @Autowired
    private MessageServer messageServer;


    @Override
    public void onMessage(MapRecord<String, String, String> message) {
        try {
            String stream = message.getStream();
            RecordId id = message.getId();
            Map<String, String> map = message.getValue();
            // 业务处理
            String busId = StringUtils.isNotBlank(map.get("busId")) ? map.get("busId").replaceAll("\"","") : null;
            String tableName = map.get("tableName").replaceAll("\"","");
            String dwdm = StringUtils.isNotBlank(map.get("dwdm")) ? map.get("dwdm").replaceAll("\"","") : null;
            log.info("[手动ACK]接收到一个消息 stream:[{}],id:[{}],value:[{}]", stream, id, map);
            messageServer.deal(busId,tableName,dwdm);
            redisTemplate.opsForStream().acknowledge(stream, GROUP, id.getValue());
            //消费完毕删除该条消息
            redisTemplate.opsForStream().delete(GROUP, id.getValue());
        } catch (Exception e) {
            log.error("第一次处理消息失败",e);
        }
    }


}