package com.unis.hlht.server.server.datashare;

import com.unis.hlht.server.common.restconfig.RestNational;
import com.unis.hlht.server.dto.datashare.DataShareParasDTO;
import com.unis.hlht.server.server.apimappingtable.ApiMappingTableServer;
import com.unis.hlht.server.server.tabledata.TableDataServer;
import com.unis.hlht.server.utils.DateUtil;
import com.unis.hlht.server.utils.SecureMngr;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * @description:数据共享服务
 * @author:马伟栋
 * @version:v1.0
 * @create:2019/02/19-13:43
 **/
@Slf4j
@Service
@SuppressWarnings("all")
public class DataShareServer {
    //国家局共享数据传输完成标志:0-未传输完成 1-传输完成
    private static final Integer TransmitUndone = 0;
    private static final Integer TransmitComplete = 1;

    @Value("${uid}")
    private String uid;

    @Value("${localprikey}")
    private String localPrivateKey;

    @Autowired
    private RestNational restNational;

    @Autowired
    private ApiMappingTableServer mappingTableServer;

    @Autowired
    private TableDataServer tableDataServer;

    /**
     * 数据共享处理
     *
     * @return响应码
     */
    public synchronized void dataShare(String api) throws Exception {
        Integer isTransmitComplete = null;
        String nextpointer = null;
        do {
            //向国家局平台发送请求
            Map resultMap = restNational.dataShareFromNational(parasDataIntegration(nextpointer, api), api);
            String retcode = (String) resultMap.get("retcode");
            if (retcode.equalsIgnoreCase("200")) {
                //是否传输完成标志：0-未传输完成 1-传输完成
                isTransmitComplete = (Integer) resultMap.get("isTransmitComplete");
                //下次获取数据的起始位置
                nextpointer = (String) resultMap.get("nextpointer");
                //保存下次获取数据的起始位置
                mappingTableServer.updatePointer(api, nextpointer);
                //业务数据持久化
                Object data = resultMap.get("data");
                if (!(data instanceof List)) {
                    String shareData = SecureMngr.decryptByPriKey((String) data, localPrivateKey);
                    tableDataServer.insertShareDataToDB(shareData, api);
                }
            } else {
                log.error("数据共享" + api + "接口请求异常:retcode:" + retcode + " retMsg:" + resultMap.get("retMsg"));
            }
        } while (TransmitUndone.equals(isTransmitComplete));
    }


    /**
     * 请求参数整合
     *
     * @param tabledata 表数据
     * @param orderid   指令ID
     */
    private DataShareParasDTO parasDataIntegration(String nextpointer, String api) throws Exception {
        DataShareParasDTO parasDTO = new DataShareParasDTO();
        parasDTO.setUserid(uid);
        parasDTO.setAccess_token(getAccessToken());
        //下次获取数据的起始位置
        if (nextpointer == null) {
            //查询数据起始位置
            Object pointer = mappingTableServer.findPointerByApi(api);
            if (pointer == null) {
                parasDTO.setPointer("0");
            } else {
                parasDTO.setPointer((String) pointer);
            }
        } else {
            parasDTO.setPointer(nextpointer);
        }
        return parasDTO;
    }

    /**
     * 身份签名
     *
     * @return
     */
    private String getAccessToken() throws Exception {
        //对身份信息进行本地私钥签名
        String accessToken = uid + "_" + DateUtil.getNowDateFormat("yyyy-MM-dd");
        return SecureMngr.sign(accessToken.getBytes("UTF-8"), localPrivateKey);
    }

}
