package com.unis.hlht.server.server.instruction;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.unis.hlht.server.common.UploadResponse;
import com.unis.hlht.server.common.restconfig.RestNational;
import com.unis.hlht.server.dto.instruction.DataParas;
import com.unis.hlht.server.dto.instruction.InstructionParasDTO;
import com.unis.hlht.server.dto.instruction.UpLoadDTO;
import com.unis.hlht.server.po.table.DataUploadMemoPO;
import com.unis.hlht.server.server.apimappingtable.ApiMappingTableServer;
import com.unis.hlht.server.server.tabledata.TableDataServer;
import com.unis.hlht.server.server.uploadmemo.DataUploadMemoServer;
import com.unis.hlht.server.utils.*;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.Reader;
import java.sql.Clob;
import java.sql.SQLException;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.*;

/**
 * @description:指令受控服务
 * @author:马伟栋
 * @version:v1.0
 * @create:2019/02/19-13:43
 **/
@Slf4j
@Service
@SuppressWarnings("all")
public class InstructionServer {

    @Value("${uid}")
    private String uid;

    @Value("${localprikey}")
    private String localPrivateKey;

    @Value("${nationalpubkey}")
    private String nationalPublicKey;

    @Value("${baseFilePath}")
    private String baseFilePath;

    @Autowired
    private TableDataServer tableDataServer;

    @Autowired
    private RestNational restNational;

    @Autowired
    private DataUploadMemoServer dataUploadMemoServer;

    @Autowired
    private ApiMappingTableServer apiMappingTableServer;

    @Autowired
    private RedisUtils redisUtils;

    /**
     * 心跳指令处理
     *
     * @return响应码
     */
    public ResponseCode heartBeat() {
        // 记录日志
        log.info("心跳指令响应成功。");
        return ResponseCode.success();
    }

    /**
     * 数据指令处理
     *
     * @return响应码
     */
    public synchronized ResponseCode dataUpload(InstructionParasDTO dto) throws Exception {
        String orderid = StringUtils.isNotBlank(dto.getOrderid()) ?
                dto.getOrderid() :
                (redisUtils.get("orderid") == null ? null : redisUtils.get("orderid").toString());
        if (StringUtils.isBlank(orderid)) {
            throw new RuntimeException("orderid为空,等待60分钟后再次处理");
        }
        String depDwdm = dto.getDepDwdm();
        DataParas data = dto.getData();
        String busId = dto.getBusId();
        Integer everyUploadDateNum = dto.getEveryUploadDateNum();
        if (StringUtils.isNotEmpty(depDwdm) && depDwdm.contains(";")) {
            String[] depDwdmSplit = depDwdm.split(";");
            for (String dwdm : depDwdmSplit) {
                try {
                    beginUpload(data, orderid, dwdm, everyUploadDateNum, busId);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        } else {
            beginUpload(data, orderid, depDwdm, everyUploadDateNum, busId);
        }
        log.info("数据指令处理完成，orderId=" + orderid);
        return ResponseCode.success();
    }

    @Transactional
    public void beginUpload(DataParas data, String orderId, String depDwdm, Integer everyUploadDateNum, String busId) throws Exception {
        if (data.getContent() != null) {
            data.setStarttime("1500-01-01 00:00:00");
            // 接口内容
            String[] contents = data.getContent().split(";");
            for (String content : contents) {
                // 根据接口查找表名
                String tableName = apiMappingTableServer.findTableNameByApi(content);
//                if (StringUtils.isBlank(tableName) || "ODS_UP_WJXXJK".equalsIgnoreCase(tableName)) {
                if (StringUtils.isBlank(tableName)) {
                    continue;
                } else {
                    tableName = tableName.trim();
                }
                // 每50条数据上传一次
                Integer pageSize = 50;
                if (everyUploadDateNum != null && everyUploadDateNum != 0) {
                    pageSize = everyUploadDateNum;
                }
                if (content.equalsIgnoreCase("1109")
                        || content.equalsIgnoreCase("1307")
                        || content.equalsIgnoreCase("1308")
                        ||content.equalsIgnoreCase("2409")
                        || content.equalsIgnoreCase("2432")
                        || content.equalsIgnoreCase("2433")) {
                    // 文件信息接口每1条数据上传一次(数据较大)
                    pageSize = 1;
                }
                //总记录数量
                Integer dataTatalSize = tableDataServer.findDataCount(tableName, depDwdm, data.getStarttime(), data.getEndtime(), busId);
                Integer pageIndex = 0;
                int count = 1;
                int totalUploadSize = 0;
                // 根据表名和时间查找对应表数据
                List<Map> tabledata = tableDataServer.findAllByLoadDate(tableName, depDwdm, data.getStarttime(),
                        data.getEndtime(), pageSize, pageIndex, busId);
                Integer dataSize = tabledata.size();
                totalUploadSize += dataSize;

                log.info(content + "--数据处理开始，数据总量--" + dataTatalSize);
                while (dataSize > 0) {
                    List<String> ids = HandleUploadData(tabledata, content);
                    // 数据上传
                    UploadResponse uploadResponse = uploadData(tabledata, orderId, content, dataSize);
                    String code = uploadResponse.getCode();
                    String result = uploadResponse.getResult();
                    if (StringUtils.equalsIgnoreCase(code, "200")) {
                        // 根据表名和数据id更新上传标记为1：已上传
                        tableDataServer.updateIsUploadToTrueByIds(tableName, ids);
                        redisUtils.set("orderid", orderId);
                    } else {
                        pageIndex += pageSize;
                        pageSize += pageSize;
                    }

                    // 数据上传信息记录
//                    String memo = apiMappingTableServer.findMemoByApi(content);
//                    result = result
//                            + ((!"200".equals(code) && everyUploadDateNum != null)
//                            ? " 错误数据id:" + StringUtils.join(ids, ",") + ";"
//                            : "");
//                    if (result != null && result.length() < 4000) {
//                        dataUploadMemoServer
//                                .save(transTodataUploadPO(content, memo, dataSize, totalUploadSize,
//                                        tabledata.size(), code, result));
//                    }
                    log.info("接口:" + content + " 第" + +count + "次上传数据,此次上传:" + dataSize + "条 " +
                            "共上传:" + totalUploadSize + "条; 上传数据状态:code=" + code + " result=" + result);
                    tabledata = tableDataServer.findAllByLoadDate(tableName, depDwdm, data.getStarttime(),
                            data.getEndtime(), pageSize, pageIndex, busId);

                    dataSize = tabledata.size();

                    if (tabledata != null && tabledata.size() > 0) {
                        count++;
                        totalUploadSize += tabledata.size();
                    } else {
                        break;
                    }
                    if (totalUploadSize > dataTatalSize) {
                        break;
                    }
                }
                log.info(content + "--数据处理完成，数据总量--" + dataTatalSize + "\n");
            }
        } else {
            log.info("国家局下发指令：" + orderId);
        }
    }

    public List<String> HandleUploadData(List<Map> tabledata, String apiCode) throws IOException, SQLException {
        for (Map map : tabledata) {
            Set<String> keySet = map.keySet();
            for (String key : keySet) {
                Object str = map.get(key);
                if (str == null) {
                    map.put(key, "");
                }
                //临时
                else if (str.equals(" ")) {
                    map.put(key, "");
                } else if (str.equals("610011255567616X")) {
                    map.put(key, "");
                }
            }
        }
        // 分离数据id
        List<String> ids = tabledata.stream().collect(() -> new ArrayList<String>(),
                (list, tableDataMap) -> list.add((String) tableDataMap.get("id")),
                (list1, list2) -> list1.addAll(list2));
        // 去除数据中id键值对
        for (Map<String, Object> map : tabledata) {
            map.entrySet().removeIf(entry -> entry.getKey().toString().equalsIgnoreCase("id"));
            map.entrySet().removeIf(entry -> entry.getKey().toString().equalsIgnoreCase("rownum"));
            map.entrySet().removeIf(entry -> entry.getKey().toString().equalsIgnoreCase("num"));
            map.entrySet().removeIf(entry -> entry.getKey().toString().equalsIgnoreCase("dwbm"));
            // 处理最后更新时间为上传时间
            map.put("zhgxsj", getBeforeMinuteTime(1));
            // 特殊接口处理
            if (("1109").equals(apiCode)||("2409").equals(apiCode)) {
                // 文件接口
                String wjlPath = this.clobToString((Clob) map.get("wjl"));
                if (wjlPath.contains("wjxxjk")) {
                    map.put("wjl", FileUtil.toHexString(
                            FileUtil.toByteArray(baseFilePath + File.separator + wjlPath)));
                }
            } else if ("1307".equals(apiCode)||"2432".equals(apiCode)) {
                // 仓内视频图像接口
                map.put("cntxwjl", FileUtil.toHexString(
                        FileUtil.toByteArray(baseFilePath + File.separator + map.get("cntxwjl").toString())));
            } else if ("1308".equals(apiCode) || "2433".equals(apiCode)) {
                // 视频监控异常事件告警信息
                map.put("spwjl", FileUtil.toHexString(
                        FileUtil.toByteArray(baseFilePath + File.separator + map.get("spwjl").toString())));
            } else if ("1102".equals(apiCode) || "2402".equals(apiCode)) {
                // 库区信息
                // 剔除展示用行政区划代码字段
                map.entrySet().removeIf(entry -> entry.getKey().toString().equalsIgnoreCase("zsyxzqhdm"));
            }
        }
        return ids;
    }


    /**
     * @param api
     * @param apiName
     * @param totalUploadSize
     * @param uploadCount
     * @param currentUploadSize
     * @param uploadResultCode
     * @param uploadResult
     * @return
     */
    private DataUploadMemoPO transTodataUploadPO(String api, String apiName, Integer totalUploadSize,
                                                 Integer uploadCount, Integer currentUploadSize, String uploadResultCode, String uploadResult) {
        DataUploadMemoPO po = new DataUploadMemoPO();
        po.setApi(api);
        po.setApiName(apiName);
        po.setTotalUploadSize(totalUploadSize);
        po.setUploadCount(uploadCount);
        po.setCurrentUploadSize(currentUploadSize);
        po.setUploadResultCode(uploadResultCode);
        po.setUploadResult(uploadResult);
        return po;
    }

    /**
     * 数据上传
     *
     * @param tabledata
     * @param orderid
     * @throws Exception
     */
    private UploadResponse uploadData(List<Map> tabledata, String orderid, String api, Integer dataSize)
            throws Exception {
        // 数据整合
        UpLoadDTO dto = dataIntegration(tabledata, orderid, dataSize);
        // 数据上传
        return restNational.uploadData2National(dto, api);
    }

    /**
     * 数据整合
     *
     * @param tabledata 表数据
     * @param orderid   指令ID
     */
    private UpLoadDTO dataIntegration(List<Map> tabledata, String orderid, Integer dataSize) throws Exception {
    		
        String jsonData = JSONObject.toJSONString(tabledata, SerializerFeature.WriteMapNullValue,
                SerializerFeature.WriteNullStringAsEmpty, SerializerFeature.WriteNullNumberAsZero,
                SerializerFeature.WriteNullBooleanAsFalse);
       
        UpLoadDTO dto = new UpLoadDTO();
        // 报文标识ID
        dto.setId(OrderID.getId());
        // 身份ID
        dto.setUid(uid);
        // 指令ID
        dto.setOrderid(orderid);
        // 身份签名
        dto.setAccess_token(getAccessToken());
        // 指令要求数据总条数
        dto.setDatalength(dataSize);
        // 数据主体
        dto.setData(getDataWithEncrypt(jsonData));
        // 数据摘要
        dto.setDigst(getDigst(jsonData));
        return dto;
    }

    /**
     * 数据加密
     *
     * @param tabledata 表数据
     * @return
     * @throws Exception
     */
    private String getDataWithEncrypt(String tabledata) throws Exception {
        // 对data进行rsa公钥加密
        return SecureMngr.encryptByPubKey(tabledata, nationalPublicKey);
    }

    /**
     * 身份签名
     *
     * @return
     */
    private String getAccessToken() throws Exception {
        // 对身份信息进行本地私钥签名
        String accessToken = uid + "_" + DateUtil.getNowDateFormat("yyyy-MM-dd");
        return SecureMngr.sign(accessToken.getBytes("UTF-8"), localPrivateKey);
    }

    /**
     * 摘要
     *
     * @param tabledata
     * @return
     */
    private String getDigst(String tabledata) {
        return MD5Utils.MD5(tabledata);
    }

    /**
     * 获取表中数据总条数
     *
     * @param api
     * @return
     */
    private Integer getDataCount(String api) {
        return tableDataServer.findDataCount(api);
    }

    /**
     * Clob类型转String
     *
     * @param clob
     * @return
     * @throws SQLException
     * @throws IOException
     */
    public String clobToString(Clob clob) throws SQLException, IOException {
        String res = "";
        Reader is = clob.getCharacterStream();
        BufferedReader br = new BufferedReader(is);
        String s = br.readLine();
        StringBuffer sb = new StringBuffer();
        while (s != null) {
            sb.append(s);
            s = br.readLine();
        }
        res = sb.toString();
        if (br != null) {
            br.close();
        }
        if (is != null) {
            is.close();
        }
        return res;
    }

    /**
     * 获取当前时间的前几分钟
     *
     * @param minutes
     * @return
     */
    private static String getBeforeMinuteTime(Integer minutes) {
        LocalDateTime now = LocalDateTime.now();
        LocalDateTime beforeMinutes = now.minusMinutes(minutes);
        DateTimeFormatter dateTimeFormatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
        return dateTimeFormatter.format(beforeMinutes);
    }

    
   /* public static void main(String[] args) {
		
    	String a = "[{"czbz":"i","jcsj":"2024-04-25 11:46:14","lssdzjh":"","cfnw":32.18,"cfns":44.58,"dep_kqdm":"","hwdm":"91630000226580802N001002900101","lszgw":28.1,"cfww":0,"lszdw":8.7,"zhgxsj":"2024-04-26 14:30:12","wsdjcdh":"91630000226580802N001002900101202208097645","cfws":0,"lspjw":15.63,"tyhwbm":"3091630000MAC6U6UT2U01038101","lswdzjh":"-4.8,1,1,1|-2.6,1,1,2|-4.8,1,1,3|-2.3,1,1,4|-3.9,1,1,5|-4.3,1,1,6|-1.8,1,1,7|-2.0,1,1,8|-2.5,1,2,1|0.2,1,2,2|-1.1,1,2,3|3.3,1,2,4|-0.3,1,2,5|-1.1,1,2,6|-0.6,1,2,7|1.4,1,2,8|-2.8,1,3,1|-1.0,1,3,2|-0.3,1,3,3|-0.2,1,3,4|2.2,1,3,5|1.9,1,3,6|-1.3,1,3,7|0.8,1,3,8|-2.6,1,4,1|-1.4,1,4,2|-0.2,1,4,3|-0.3,1,4,4|-0.5,1,4,5|1.0,1,4,6|1.9,1,4,7|-0.5,1,4,8|-2.2,1,5,1|1.4,1,5,2|2.1,1,5,3|2.9,1,5,4|2.1,1,5,5|2.9,1,5,6|2.5,1,5,7|1.5,1,5,8|-4.7,1,6,1|-4.5,1,6,2|-3.6,1,6,3|0.9,1,6,4|-1.4,1,6,5|-1.1,1,6,6|-2.1,1,6,7|0.1,1,6,8|-1.1,2,1,1|-2.9,2,1,2|-0.2,2,1,3|0.8,2,1,4|0.1,2,1,5|-1.1,2,1,6|6.8,2,1,7|5.2,2,1,8|3.6,2,2,1|7.8,2,2,2|6.9,2,2,3|6.3,2,2,4|6.4,2,2,5|6.5,2,2,6|6.7,2,2,7|8.2,2,2,8|0.9,2,3,1|6.8,2,3,2|6.1,2,3,3|5.9,2,3,4|5.2,2,3,5|5.6,2,3,6|6.3,2,3,7|7.4,2,3,8|1.4,2,4,1|6.7,2,4,2|6.4,2,4,3|6.3,2,4,4|5.9,2,4,5|5.8,2,4,6|5.8,2,4,7|7.4,2,4,8|2.9,2,5,1|6.8,2,5,2|6.6,2,5,3|6.3,2,5,4|5.6,2,5,5|5.6,2,5,6|6.2,2,5,7|7.6,2,5,8|-1.8,2,6,1|-0.5,2,6,2|0.8,2,6,3|5.9,2,6,4|3.3,2,6,5|3.5,2,6,6|0.9,2,6,7|3.9,2,6,8|-1.5,3,1,1|-4.8,3,1,2|-0.8,3,1,3|-2.3,3,1,4|1.3,3,1,5|-3.4,3,1,6|6.9,3,1,7|5.4,3,1,8|5.3,3,2,1|7.3,3,2,2|5.3,3,2,3|6.1,3,2,4|5.6,3,2,5|5.7,3,2,6|6.1,3,2,7|8.1,3,2,8|-0.1,3,3,1|4.9,3,3,2|4.4,3,3,3|4.3,3,3,4|4.8,3,3,5|4.6,3,3,6|4.4,3,3,7|6.4,3,3,8|0.3,3,4,1|4.8,3,4,2|4.4,3,4,3|4.5,3,4,4|4.0,3,4,5|4.2,3,4,6|4.0,3,4,7|5.9,3,4,8|3.8,3,5,1|5.3,3,5,2|4.6,3,5,3|5.3,3,5,4|4.3,3,5,5|4.1,3,5,6|4.2,3,5,7|5.9,3,5,8|-4.0,3,6,1|-1.5,3,6,2|-0.9,3,6,3|6.4,3,6,4|2.8,3,6,5|2.7,3,6,6|0.2,3,6,7|3.4,3,6,8|2.3,4,1,1|-1.1,4,1,2|0.2,4,1,3|-0.9,4,1,4|5.4,4,1,5|-1.1,4,1,6|7.6,4,1,7|5.6,4,1,8|7.9,4,2,1|9.3,4,2,2|9.2,4,2,3|9.6,4,2,4|9.4,4,2,5|9.3,4,2,6|9.6,4,2,7|8.9,4,2,8|4.7,4,3,1|9.3,4,3,2|7.8,4,3,3|5.8,4,3,4|7.1,4,3,5|9.1,4,3,6|8.7,4,3,7|8.9,4,3,8|2.3,4,4,1|8.3,4,4,2|7.4,4,4,3|6.6,4,4,4|7.9,4,4,5|8.3,4,4,6|7.3,4,4,7|7.7,4,4,8|4.6,4,5,1|7.4,4,5,2|7.4,4,5,3|8.3,4,5,4|7.3,4,5,5|5.2,4,5,6|7.3,4,5,7|5.8,4,5,8|-3.4,4,6,1|-2.4,4,6,2|0.7,4,6,3|5.2,4,6,4|0.3,4,6,5|3.1,4,6,6|-0.6,4,6,7|4.6,4,6,8\u0000","dep_dwdm":""},{"czbz":"i","jcsj":"2024-04-25 11:46:14","lssdzjh":"","cfnw":19.1,"cfns":58,"dep_kqdm":"","hwdm":"91630000226580802N001004500101","lszgw":19.5,"cfww":19.36,"lszdw":2.25,"zhgxsj":"2024-04-26 14:30:12","wsdjcdh":"91630000226580802N001004500101202207197475","cfws":65.36,"lspjw":8.02,"tyhwbm":"3091630000MAC6U6UT2U01059101","lswdzjh":"-4.8,1,1,1|-2.6,1,1,2|-4.8,1,1,3|-2.3,1,1,4|-3.9,1,1,5|-4.3,1,1,6|-1.8,1,1,7|-2.0,1,1,8|-2.5,1,2,1|0.2,1,2,2|-1.1,1,2,3|3.3,1,2,4|-0.3,1,2,5|-1.1,1,2,6|-0.6,1,2,7|1.4,1,2,8|-2.8,1,3,1|-1.0,1,3,2|-0.3,1,3,3|-0.2,1,3,4|2.2,1,3,5|1.9,1,3,6|-1.3,1,3,7|0.8,1,3,8|-2.6,1,4,1|-1.4,1,4,2|-0.2,1,4,3|-0.3,1,4,4|-0.5,1,4,5|1.0,1,4,6|1.9,1,4,7|-0.5,1,4,8|-2.2,1,5,1|1.4,1,5,2|2.1,1,5,3|2.9,1,5,4|2.1,1,5,5|2.9,1,5,6|2.5,1,5,7|1.5,1,5,8|-4.7,1,6,1|-4.5,1,6,2|-3.6,1,6,3|0.9,1,6,4|-1.4,1,6,5|-1.1,1,6,6|-2.1,1,6,7|0.1,1,6,8|-1.1,2,1,1|-2.9,2,1,2|-0.2,2,1,3|0.8,2,1,4|0.1,2,1,5|-1.1,2,1,6|6.8,2,1,7|5.2,2,1,8|3.6,2,2,1|7.8,2,2,2|6.9,2,2,3|6.3,2,2,4|6.4,2,2,5|6.5,2,2,6|6.7,2,2,7|8.2,2,2,8|0.9,2,3,1|6.8,2,3,2|6.1,2,3,3|5.9,2,3,4|5.2,2,3,5|5.6,2,3,6|6.3,2,3,7|7.4,2,3,8|1.4,2,4,1|6.7,2,4,2|6.4,2,4,3|6.3,2,4,4|5.9,2,4,5|5.8,2,4,6|5.8,2,4,7|7.4,2,4,8|2.9,2,5,1|6.8,2,5,2|6.6,2,5,3|6.3,2,5,4|5.6,2,5,5|5.6,2,5,6|6.2,2,5,7|7.6,2,5,8|-1.8,2,6,1|-0.5,2,6,2|0.8,2,6,3|5.9,2,6,4|3.3,2,6,5|3.5,2,6,6|0.9,2,6,7|3.9,2,6,8|-1.5,3,1,1|-4.8,3,1,2|-0.8,3,1,3|-2.3,3,1,4|1.3,3,1,5|-3.4,3,1,6|6.9,3,1,7|5.4,3,1,8|5.3,3,2,1|7.3,3,2,2|5.3,3,2,3|6.1,3,2,4|5.6,3,2,5|5.7,3,2,6|6.1,3,2,7|8.1,3,2,8|-0.1,3,3,1|4.9,3,3,2|4.4,3,3,3|4.3,3,3,4|4.8,3,3,5|4.6,3,3,6|4.4,3,3,7|6.4,3,3,8|0.3,3,4,1|4.8,3,4,2|4.4,3,4,3|4.5,3,4,4|4.0,3,4,5|4.2,3,4,6|4.0,3,4,7|5.9,3,4,8|3.8,3,5,1|5.3,3,5,2|4.6,3,5,3|5.3,3,5,4|4.3,3,5,5|4.1,3,5,6|4.2,3,5,7|5.9,3,5,8|-4.0,3,6,1|-1.5,3,6,2|-0.9,3,6,3|6.4,3,6,4|2.8,3,6,5|2.7,3,6,6|0.2,3,6,7|3.4,3,6,8|2.3,4,1,1|-1.1,4,1,2|0.2,4,1,3|-0.9,4,1,4|5.4,4,1,5|-1.1,4,1,6|7.6,4,1,7|5.6,4,1,8|7.9,4,2,1|9.3,4,2,2|9.2,4,2,3|9.6,4,2,4|9.4,4,2,5|9.3,4,2,6|9.6,4,2,7|8.9,4,2,8|4.7,4,3,1|9.3,4,3,2|7.8,4,3,3|5.8,4,3,4|7.1,4,3,5|9.1,4,3,6|8.7,4,3,7|8.9,4,3,8|2.3,4,4,1|8.3,4,4,2|7.4,4,4,3|6.6,4,4,4|7.9,4,4,5|8.3,4,4,6|7.3,4,4,7|7.7,4,4,8|4.6,4,5,1|7.4,4,5,2|7.4,4,5,3|8.3,4,5,4|7.3,4,5,5|5.2,4,5,6|7.3,4,5,7|5.8,4,5,8|-3.4,4,6,1|-2.4,4,6,2|0.7,4,6,3|5.2,4,6,4|0.3,4,6,5|3.1,4,6,6|-0.6,4,6,7|4.6,4,6,8\u0000","dep_dwdm":""},{"czbz":"i","jcsj":"2024-04-25 11:46:14","lssdzjh":"","cfnw":18.1,"cfns":63,"dep_kqdm":"","hwdm":"91630000226580802N001004600101","lszgw":18.5,"cfww":19.39,"lszdw":3.75,"zhgxsj":"2024-04-26 14:30:12","wsdjcdh":"91630000226580802N001004600101202207197476","cfws":65.24,"lspjw":10.25,"tyhwbm":"3091630000MAC6U6UT2U01060101","lswdzjh":"-4.8,1,1,1|-2.6,1,1,2|-4.8,1,1,3|-2.3,1,1,4|-3.9,1,1,5|-4.3,1,1,6|-1.8,1,1,7|-2.0,1,1,8|-2.5,1,2,1|0.2,1,2,2|-1.1,1,2,3|3.3,1,2,4|-0.3,1,2,5|-1.1,1,2,6|-0.6,1,2,7|1.4,1,2,8|-2.8,1,3,1|-1.0,1,3,2|-0.3,1,3,3|-0.2,1,3,4|2.2,1,3,5|1.9,1,3,6|-1.3,1,3,7|0.8,1,3,8|-2.6,1,4,1|-1.4,1,4,2|-0.2,1,4,3|-0.3,1,4,4|-0.5,1,4,5|1.0,1,4,6|1.9,1,4,7|-0.5,1,4,8|-2.2,1,5,1|1.4,1,5,2|2.1,1,5,3|2.9,1,5,4|2.1,1,5,5|2.9,1,5,6|2.5,1,5,7|1.5,1,5,8|-4.7,1,6,1|-4.5,1,6,2|-3.6,1,6,3|0.9,1,6,4|-1.4,1,6,5|-1.1,1,6,6|-2.1,1,6,7|0.1,1,6,8|-1.1,2,1,1|-2.9,2,1,2|-0.2,2,1,3|0.8,2,1,4|0.1,2,1,5|-1.1,2,1,6|6.8,2,1,7|5.2,2,1,8|3.6,2,2,1|7.8,2,2,2|6.9,2,2,3|6.3,2,2,4|6.4,2,2,5|6.5,2,2,6|6.7,2,2,7|8.2,2,2,8|0.9,2,3,1|6.8,2,3,2|6.1,2,3,3|5.9,2,3,4|5.2,2,3,5|5.6,2,3,6|6.3,2,3,7|7.4,2,3,8|1.4,2,4,1|6.7,2,4,2|6.4,2,4,3|6.3,2,4,4|5.9,2,4,5|5.8,2,4,6|5.8,2,4,7|7.4,2,4,8|2.9,2,5,1|6.8,2,5,2|6.6,2,5,3|6.3,2,5,4|5.6,2,5,5|5.6,2,5,6|6.2,2,5,7|7.6,2,5,8|-1.8,2,6,1|-0.5,2,6,2|0.8,2,6,3|5.9,2,6,4|3.3,2,6,5|3.5,2,6,6|0.9,2,6,7|3.9,2,6,8|-1.5,3,1,1|-4.8,3,1,2|-0.8,3,1,3|-2.3,3,1,4|1.3,3,1,5|-3.4,3,1,6|6.9,3,1,7|5.4,3,1,8|5.3,3,2,1|7.3,3,2,2|5.3,3,2,3|6.1,3,2,4|5.6,3,2,5|5.7,3,2,6|6.1,3,2,7|8.1,3,2,8|-0.1,3,3,1|4.9,3,3,2|4.4,3,3,3|4.3,3,3,4|4.8,3,3,5|4.6,3,3,6|4.4,3,3,7|6.4,3,3,8|0.3,3,4,1|4.8,3,4,2|4.4,3,4,3|4.5,3,4,4|4.0,3,4,5|4.2,3,4,6|4.0,3,4,7|5.9,3,4,8|3.8,3,5,1|5.3,3,5,2|4.6,3,5,3|5.3,3,5,4|4.3,3,5,5|4.1,3,5,6|4.2,3,5,7|5.9,3,5,8|-4.0,3,6,1|-1.5,3,6,2|-0.9,3,6,3|6.4,3,6,4|2.8,3,6,5|2.7,3,6,6|0.2,3,6,7|3.4,3,6,8|2.3,4,1,1|-1.1,4,1,2|0.2,4,1,3|-0.9,4,1,4|5.4,4,1,5|-1.1,4,1,6|7.6,4,1,7|5.6,4,1,8|7.9,4,2,1|9.3,4,2,2|9.2,4,2,3|9.6,4,2,4|9.4,4,2,5|9.3,4,2,6|9.6,4,2,7|8.9,4,2,8|4.7,4,3,1|9.3,4,3,2|7.8,4,3,3|5.8,4,3,4|7.1,4,3,5|9.1,4,3,6|8.7,4,3,7|8.9,4,3,8|2.3,4,4,1|8.3,4,4,2|7.4,4,4,3|6.6,4,4,4|7.9,4,4,5|8.3,4,4,6|7.3,4,4,7|7.7,4,4,8|4.6,4,5,1|7.4,4,5,2|7.4,4,5,3|8.3,4,5,4|7.3,4,5,5|5.2,4,5,6|7.3,4,5,7|5.8,4,5,8|-3.4,4,6,1|-2.4,4,6,2|0.7,4,6,3|5.2,4,6,4|0.3,4,6,5|3.1,4,6,6|-0.6,4,6,7|4.6,4,6,8\u0000","dep_dwdm":""},{"czbz":"i","jcsj":"2024-04-25 11:46:14","lssdzjh":"","cfnw":30.56,"cfns":35.72,"dep_kqdm":"","hwdm":"91630000226580802N001002700101","lszgw":27.3,"cfww":0,"lszdw":6.1,"zhgxsj":"2024-04-26 14:30:12","wsdjcdh":"91630000226580802N001002700101202208097643","cfws":0,"lspjw":15.43,"tyhwbm":"3091630000MAC6U6UT2U01029101","lswdzjh":"-4.8,1,1,1|-2.6,1,1,2|-4.8,1,1,3|-2.3,1,1,4|-3.9,1,1,5|-4.3,1,1,6|-1.8,1,1,7|-2.0,1,1,8|-2.5,1,2,1|0.2,1,2,2|-1.1,1,2,3|3.3,1,2,4|-0.3,1,2,5|-1.1,1,2,6|-0.6,1,2,7|1.4,1,2,8|-2.8,1,3,1|-1.0,1,3,2|-0.3,1,3,3|-0.2,1,3,4|2.2,1,3,5|1.9,1,3,6|-1.3,1,3,7|0.8,1,3,8|-2.6,1,4,1|-1.4,1,4,2|-0.2,1,4,3|-0.3,1,4,4|-0.5,1,4,5|1.0,1,4,6|1.9,1,4,7|-0.5,1,4,8|-2.2,1,5,1|1.4,1,5,2|2.1,1,5,3|2.9,1,5,4|2.1,1,5,5|2.9,1,5,6|2.5,1,5,7|1.5,1,5,8|-4.7,1,6,1|-4.5,1,6,2|-3.6,1,6,3|0.9,1,6,4|-1.4,1,6,5|-1.1,1,6,6|-2.1,1,6,7|0.1,1,6,8|-1.1,2,1,1|-2.9,2,1,2|-0.2,2,1,3|0.8,2,1,4|0.1,2,1,5|-1.1,2,1,6|6.8,2,1,7|5.2,2,1,8|3.6,2,2,1|7.8,2,2,2|6.9,2,2,3|6.3,2,2,4|6.4,2,2,5|6.5,2,2,6|6.7,2,2,7|8.2,2,2,8|0.9,2,3,1|6.8,2,3,2|6.1,2,3,3|5.9,2,3,4|5.2,2,3,5|5.6,2,3,6|6.3,2,3,7|7.4,2,3,8|1.4,2,4,1|6.7,2,4,2|6.4,2,4,3|6.3,2,4,4|5.9,2,4,5|5.8,2,4,6|5.8,2,4,7|7.4,2,4,8|2.9,2,5,1|6.8,2,5,2|6.6,2,5,3|6.3,2,5,4|5.6,2,5,5|5.6,2,5,6|6.2,2,5,7|7.6,2,5,8|-1.8,2,6,1|-0.5,2,6,2|0.8,2,6,3|5.9,2,6,4|3.3,2,6,5|3.5,2,6,6|0.9,2,6,7|3.9,2,6,8|-1.5,3,1,1|-4.8,3,1,2|-0.8,3,1,3|-2.3,3,1,4|1.3,3,1,5|-3.4,3,1,6|6.9,3,1,7|5.4,3,1,8|5.3,3,2,1|7.3,3,2,2|5.3,3,2,3|6.1,3,2,4|5.6,3,2,5|5.7,3,2,6|6.1,3,2,7|8.1,3,2,8|-0.1,3,3,1|4.9,3,3,2|4.4,3,3,3|4.3,3,3,4|4.8,3,3,5|4.6,3,3,6|4.4,3,3,7|6.4,3,3,8|0.3,3,4,1|4.8,3,4,2|4.4,3,4,3|4.5,3,4,4|4.0,3,4,5|4.2,3,4,6|4.0,3,4,7|5.9,3,4,8|3.8,3,5,1|5.3,3,5,2|4.6,3,5,3|5.3,3,5,4|4.3,3,5,5|4.1,3,5,6|4.2,3,5,7|5.9,3,5,8|-4.0,3,6,1|-1.5,3,6,2|-0.9,3,6,3|6.4,3,6,4|2.8,3,6,5|2.7,3,6,6|0.2,3,6,7|3.4,3,6,8|2.3,4,1,1|-1.1,4,1,2|0.2,4,1,3|-0.9,4,1,4|5.4,4,1,5|-1.1,4,1,6|7.6,4,1,7|5.6,4,1,8|7.9,4,2,1|9.3,4,2,2|9.2,4,2,3|9.6,4,2,4|9.4,4,2,5|9.3,4,2,6|9.6,4,2,7|8.9,4,2,8|4.7,4,3,1|9.3,4,3,2|7.8,4,3,3|5.8,4,3,4|7.1,4,3,5|9.1,4,3,6|8.7,4,3,7|8.9,4,3,8|2.3,4,4,1|8.3,4,4,2|7.4,4,4,3|6.6,4,4,4|7.9,4,4,5|8.3,4,4,6|7.3,4,4,7|7.7,4,4,8|4.6,4,5,1|7.4,4,5,2|7.4,4,5,3|8.3,4,5,4|7.3,4,5,5|5.2,4,5,6|7.3,4,5,7|5.8,4,5,8|-3.4,4,6,1|-2.4,4,6,2|0.7,4,6,3|5.2,4,6,4|0.3,4,6,5|3.1,4,6,6|-0.6,4,6,7|4.6,4,6,8\u0000","dep_dwdm":""},{"czbz":"i","jcsj":"2024-04-25 11:46:14","lssdzjh":"","cfnw":27.34,"cfns":49.78,"dep_kqdm":"","hwdm":"91630000226580802N001002800101","lszgw":26,"cfww":0,"lszdw":-0.9,"zhgxsj":"2024-04-26 14:30:12","wsdjcdh":"91630000226580802N001002800101202208097644","cfws":0,"lspjw":11.07,"tyhwbm":"3091630000MAC6U6UT2U01030101","lswdzjh":"-4.8,1,1,1|-2.6,1,1,2|-4.8,1,1,3|-2.3,1,1,4|-3.9,1,1,5|-4.3,1,1,6|-1.8,1,1,7|-2.0,1,1,8|-2.5,1,2,1|0.2,1,2,2|-1.1,1,2,3|3.3,1,2,4|-0.3,1,2,5|-1.1,1,2,6|-0.6,1,2,7|1.4,1,2,8|-2.8,1,3,1|-1.0,1,3,2|-0.3,1,3,3|-0.2,1,3,4|2.2,1,3,5|1.9,1,3,6|-1.3,1,3,7|0.8,1,3,8|-2.6,1,4,1|-1.4,1,4,2|-0.2,1,4,3|-0.3,1,4,4|-0.5,1,4,5|1.0,1,4,6|1.9,1,4,7|-0.5,1,4,8|-2.2,1,5,1|1.4,1,5,2|2.1,1,5,3|...";
	
    }*/
}
