package com.unis.hlht.server.server.message;

import com.unis.hlht.server.dto.instruction.DataParas;
import com.unis.hlht.server.dto.instruction.InstructionParasDTO;
import com.unis.hlht.server.enums.instruction.InstructionTypeEnum;
import com.unis.hlht.server.server.apimappingtable.ApiMappingTableServer;
import com.unis.hlht.server.server.instruction.InstructionServer;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * @description:处理通知服务类
 * @author:马伟栋
 * @version:v1.0
 * @create:2019/07/09-11:23
 **/
@Service
@SuppressWarnings("all")
public class MessageServer {

    @Autowired
    private ApiMappingTableServer apiMappingTableServer;

    @Autowired
    private InstructionServer instructionServer;


    /**
     * 处理通知
     *
     * @param busId     业务数据id
     * @param tableName 存储业务数据的表名
     * @param dwdm      单位统一社会信用代码
     */
    @Transactional
    public void deal(String busId, String tableName, String dwdm) throws Exception {
        if (StringUtils.isNotBlank(tableName)) {
            // 表名对应的api编码
            String api = apiMappingTableServer.findApiByTableName(tableName);
            // 模拟发送数据指令
            DataParas dataParas = new DataParas();
            dataParas.setStarttime("1000-01-01 00:00:00");
            dataParas.setEndtime("2099-01-01 00:00:00");
            dataParas.setContent(api);
            InstructionParasDTO instructionParasDTO = new InstructionParasDTO();
            instructionParasDTO.setType(InstructionTypeEnum.dataInstruction.getCode());
            instructionParasDTO.setData(dataParas);
            instructionParasDTO.setBusId(busId);
            instructionParasDTO.setEveryUploadDateNum(1);
            instructionParasDTO.setDepDwdm(dwdm);
//            instructionParasDTO.setOrderid("808080828c148533018c4240d05a61ea");
            instructionServer.dataUpload(instructionParasDTO);
        }
    }

    public void dealAllApi() throws Exception {
        // 模拟发送数据指令
        DataParas dataParas = new DataParas();
        dataParas.setStarttime("1000-01-01 00:00:00");
        dataParas.setEndtime("2099-01-01 00:00:00");
        dataParas.setContent("1101;1102;1103;1104;1105;1106;1107;1108;1109;1110;1111;1112;1113;1114;1201;1202;1203;1204;1205;1206;1207;1208;1209;1210;1211;1212;1301;1302;1303;1304;1305;1306;1307;1308;1309;1310;1401;1402;1403;1404;1405;1501");
        InstructionParasDTO instructionParasDTO = new InstructionParasDTO();
        instructionParasDTO.setType(InstructionTypeEnum.dataInstruction.getCode());
        instructionParasDTO.setData(dataParas);
        instructionParasDTO.setEveryUploadDateNum(1);
        instructionServer.dataUpload(instructionParasDTO);
    }

}
