package com.unis.hlht.server.server.tabledata;

import com.unis.hlht.server.mapper.tablecommentmap.TableCommentMapper;
import com.unis.hlht.server.mapper.tabledata.TableDataMapper;
import com.unis.hlht.server.po.table.TableCommentPO;
import com.unis.hlht.server.po.table.TableInfoPO;
import com.unis.hlht.server.server.apimappingtable.ApiMappingTableServer;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * @description:根据api操作表数据服务
 * @author:马伟栋
 * @version:v1.0
 * @create:2019/02/19-13:43
 **/

@Service
@SuppressWarnings("all")
public class TableDataServer {

    @Autowired
    private TableDataMapper mapper;

    @Autowired
    private ApiMappingTableServer mappingTableServer;

    @Autowired
    private TableCommentMapper tableCommentMapper;

    /**
     * 根据api查询对应表中数据
     *
     * @return结果
     */
    public List<Map> findAllByLoadDate(String tableName, String depDwdm, String startTime, String endTime,
                                       Integer pageSize, Integer pageIndex, String busId) {
        List<Map> tableDatas = null;
        if (StringUtils.isNotBlank(busId)) {
        	if(tableName.equals("ODS_UP_WSDJCXXJK")){//温湿度检测
        		tableDatas = mapper.findByIdLOB(tableName, busId,pageSize,pageIndex);
        	}else if(tableName.equals("ODS_UP_QTJCXXJK")){//气体检测
                tableDatas = mapper.findByIdQt(tableName, busId,pageSize,pageIndex);
        	}else{
                tableDatas = mapper.findById(tableName, busId,pageSize,pageIndex);
        	}
        } else {
            Map params = paramsTransToMap(tableName, depDwdm, startTime, endTime, pageSize, pageIndex);
            if(tableName.equals("ODS_UP_WSDJCXXJK")){//温湿度检测
                tableDatas = mapper.findAllByLoadDateLOB(params);
            }else if(tableName.equals("ODS_UP_QTJCXXJK")){//气体检测
                tableDatas = mapper.findAllByLoadDateQt(params);
            }else{
                tableDatas = mapper.findAllByLoadDate(params);

            }
        }
        List<Map> resultTableDatas = new ArrayList<>();
        for (Map tableData : tableDatas) {
            Map resultMap = new HashMap<>();
            Set<String> set = tableData.keySet();
            for (String key : set) {
                if ("LOAD_DATE".equalsIgnoreCase(key) || "IS_UPLOAD".equalsIgnoreCase(key)) {
                    continue;
                }
                String newKey = key.toLowerCase();
                resultMap.put(newKey, tableData.get(key));
            }
            resultTableDatas.add(resultMap);
        }
        return resultTableDatas;
    }

    /**
     * 根据api获取表中数据总条数
     *
     * @param apiName
     * @return
     */
    public Integer findDataCount(String api) {
        Map map = paramsTransToMap(api, null, null, null, null, null);
        return mapper.findDataCount(map);
    }

    /**
     * 根据api获取表中数据总条数
     *
     * @param string
     * @param apiName
     * @return
     */
    public Integer findDataCount(String api, String depDwdm, String beginTime, String endTime, String busId) {
        if (StringUtils.isNotBlank(busId)) {
            return mapper.findDataCountById(api, busId);
        } else {
            Map map = paramsTransToMap(api, depDwdm, beginTime, endTime, null, null);
            return mapper.findDataCount(map);
        }
    }

    /**
     * 参数转换为map类型
     *
     * @param tableName
     * @param startTime
     * @param endTime
     * @param endTime2
     * @return
     */
    private Map paramsTransToMap(String tableName, String depDwdm, String startTime, String endTime, Integer pageSize, Integer pageIndex) {
        Map params = new HashMap<String, String>();
        params.put("tableName", tableName);
        params.put("startTime", startTime);
        params.put("endTime", endTime);
        params.put("pageSize", pageSize);
        params.put("depDwdm", StringUtils.isNotBlank(depDwdm) ? depDwdm + "%" : null);
        params.put("pageIndex", pageIndex);
        params.put("selectByDwdmOfCol", StringUtils.isNotBlank(depDwdm) ? getSelectByDwdmOfCol(tableName) : null);
        return params;
    }

    /**
     * 根据api将共享数据持久化
     *
     * @param data 共享数据
     * @param api  api
     */
    public void insertShareDataToDB(String data, String api) {
        String tableName = mappingTableServer.findTableNameByApi(api);
        List<TableInfoPO> tableInfoPOS = mapper.findColumnNameAndDataTypeByTableName(tableName);
        mapper.insertShareDataToDB(data, tableName, tableInfoPOS);
    }

    /**
     * 根据表名和数据id更新上传标记为1：已上传
     *
     * @param tableName
     * @param ids
     */
    public void updateIsUploadToTrueByIds(String tableName, List<String> ids) {
        HashMap<String, Object> params = new HashMap<>();
        params.put("tableName", tableName);
        params.put("ids", ids);
        mapper.updateIsUploadToTrueByIds(params);
    }

    private String getSelectByDwdmOfCol(String tableName) {
        TableCommentPO tableCommentPO = tableCommentMapper.selectByTableName(tableName);
        return tableCommentPO.getDELETE_COL();
    }

}
