package com.unis.hlht.server.utils;

import sun.misc.BASE64Decoder;

import java.io.*;

/**
 * 将文件转为二进制流工具类--上传7.1.1.7　文件信息数据接口（中的文件流）
 *
 * @author wujinhu
 */
public class FileUtil {

    /**
     * 根据文件路径将文件转为二进制数组
     *
     * @param filePath:文件路径
     * @return
     */
    public static byte[] file2byte(String filePath) {
        byte[] buffer = null;
        try {
            File file = new File(filePath);
            FileInputStream fis = new FileInputStream(file);
            ByteArrayOutputStream bos = new ByteArrayOutputStream();
            byte[] b = new byte[1024];
            int n;
            while ((n = fis.read(b)) != -1) {
                bos.write(b, 0, n);
            }
            fis.close();
            bos.close();
            buffer = bos.toByteArray();
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
        return buffer;
    }

    /**
     * 将二进制数组转为字符串
     *
     * @param byteArray
     * @return
     */
    public static String toHexString(byte[] byteArray) {
        if (byteArray == null || byteArray.length < 1)
            throw new IllegalArgumentException(
                    "this byteArray must not be null or empty");
        final StringBuilder hexString = new StringBuilder();
        for (int i = 0; i < byteArray.length; i++) {
            if ((byteArray[i] & 0xff) < 0x10) {
                // 0~F前面不零
                hexString.append("0");
            }
            hexString.append(Integer.toHexString(0xFF & byteArray[i]));
        }
        return hexString.toString().toLowerCase();
    }

    /**
     * 16进制字符串转2进制byte数组
     *
     * @param hex
     * @return
     */
    public static byte[] hexStringToByte(String hex) {
        int m = 0, n = 0;
        // 每两个字符描述一个字节
        int byteLen = hex.length() / 2;
        byte[] ret = new byte[byteLen];
        for (int i = 0; i < byteLen; i++) {
            m = i * 2 + 1;
            n = m + 1;
            int intVal = Integer.decode("0x" + hex.substring(i * 2, m) + hex.substring(m, n));
            ret[i] = (byte) intVal;
        }
        return ret;
    }

    /**
     * 2进制字符转2进制byte数组
     *
     * @param imgBase
     * @return
     */
    public static byte[] binaryStringToByte(String imgBase) throws IOException {
        BASE64Decoder decoder = new BASE64Decoder();
        // Base64解码
        byte[] b = decoder.decodeBuffer(imgBase);
        for (int i = 0; i < b.length; ++i) {
            // 调整异常数据
            if (b[i] < 0) {
                b[i] += 256;
            }
        }
        return b;
    }

    public static void saveFile(String imgStr, String filePath, String fileName) {
        FileOutputStream out = null;
        String filePathAndName = filePath + File.separator + fileName;
        try {
            byte[] bytes = null;
            if (imgStr.startsWith("ff")) {
                bytes = FileUtil.hexStringToByte(imgStr.toUpperCase());
            } else {
                bytes = FileUtil.binaryStringToByte(imgStr);
            }
            File file = new File(filePathAndName);
            File parentFile = file.getParentFile();
            if (!parentFile.exists()) {
                parentFile.mkdirs();
            }
            out = new FileOutputStream(file);
            out.write(bytes);
            out.flush();
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            if (out != null) {
                try {
                    out.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
    }


    /**
     * the traditional io way
     *
     * @param filePathAndName
     * @return
     * @throws IOException
     */
    public static byte[] toByteArray(String filePathAndName) throws IOException {
        File f = new File(filePathAndName);
        if (!f.exists()) {
            throw new FileNotFoundException(filePathAndName);
        }
        ByteArrayOutputStream bos = new ByteArrayOutputStream((int) f.length());
        BufferedInputStream in = null;
        try {
            in = new BufferedInputStream(new FileInputStream(f));
            int buf_size = 1024;
            byte[] buffer = new byte[buf_size];
            int len = 0;
            while (-1 != (len = in.read(buffer, 0, buf_size))) {
                bos.write(buffer, 0, len);
            }
            return bos.toByteArray();
        } catch (IOException e) {
            e.printStackTrace();
            throw e;
        } finally {
            try {
                in.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
            bos.close();
        }
    }


}
